@@ -20,11 +20,7 @@ from gnodeclient.conf import Configuration
 from gnodeclient.store.caching_rest_store import CachingRestStore
 from gnodeclient.result.result_driver import NativeDriver
 
-__all__ = ("GNODECLIENT_VERSION", "GNODECLIENT_RELEASE", "Session", "create", "close")
-
-# The version and release status of the client
-GNODECLIENT_VERSION = "0.3.0"
-GNODECLIENT_RELEASE = "Beta"
+__all__ = ("Session", "create", "close")
 
 # A global session object.
 _MAIN_SESSION = None
